@@ -15,7 +15,7 @@ sub _do_make_path ($self, @data) {
 
   for my $folder (@create) {
     my $res
-      = $drive->connector->_ua_post($parent->url('children'), {name => $folder, folder => {}});
+      = $drive->connector->_ua_post($parent->url('children'), json => {name => $folder, folder => {}});
     Carp::confess $res->message if $res->is_error;
 
     $parent = Nuvol::Item->new($drive, {metadata => $res->json});
@@ -35,30 +35,14 @@ sub _do_remove_tree ($self) {
 
 =head1 NAME
 
-Nuvol::Office365::Folder - Role for Office 365 folders
-
-=head1 SYNOPSIS
-
-    use Nuvol::Connector;
-
-    my $connector = Nuvol::Connector->new($configfolder, 'Office365');
-    my $folder    = $connector->drive(%params)->folder($path);
+Nuvol::Office365::Folder - Internal methods for Office 365 folders
 
 =head1 DESCRIPTION
 
-L<Nuvol::Office365::Folder> is a role for Office 365 folders.
-
-=head1 CONSTRUCTOR
-
-=head2 via Nuvol::Connector
-
-    $connector = Nuvol::Connector->new($configfolder, 'Office365');
-    $folder    = $connector->drive(%params)->folder($path);
-
-Creates a L<Nuvol::Item> with applied L<Nuvol::Role::Folder> and C<Office365> roles.
+L<Nuvol::Office365::Folder> provides internal methods for Office 365 folders.
 
 =head1 SEE ALSO
 
-L<Nuvol::Item>, L<Nuvol::Role::Folder>.
+L<Nuvol::Office365>, L<Nuvol::Role::Folder>.
 
 =cut
